@@ -1,4 +1,4 @@
-# $Id: Title.pm,v 1.45.2.1 2005/08/14 21:22:29 joern Exp $
+# $Id: Title.pm,v 1.46 2005/08/01 19:09:21 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -33,6 +33,11 @@ sub set_with_vob_remove		{ shift->{with_vob_remove} 	= $_[1] }
 sub frames_per_chunk		{ shift->{frames_per_chunk}		}
 sub set_frames_per_chunk	{ shift->{frames_per_chunk} 	= $_[1] }
 
+sub info {
+	my $self = shift;
+	return $self->project->name." (#".$self->nr.")";
+}
+
 sub create_vob_dir {
 	my $self = shift; $self->trace_in;
 	
@@ -60,7 +65,7 @@ sub create_avi_dir {
 sub multipass_log_dir {				# directory for multipass logs
 	my $self = shift; $self->trace_in;
 
-	my $job = $self->project->assigned_job or croak "No job assigned";
+	my $job = $self->project->assigned_job or die "No job assigned";
 	
 	return sprintf (
 		"%s/%s/cluster/%03d-%02d-%05d",
@@ -75,7 +80,7 @@ sub multipass_log_dir {				# directory for multipass logs
 sub avi_chunks_dir {				# directory for avi chunks
 	my $self = shift; $self->trace_in;
 
-	my $job = $self->project->assigned_job or croak "No job assigned";
+	my $job = $self->project->assigned_job or die "No job assigned";
 	
 	return sprintf (
 		"%s/%03d/chunks-psu-%02d",
@@ -88,7 +93,7 @@ sub avi_chunks_dir {				# directory for avi chunks
 sub avi_file {					# transcode output file
 	my $self = shift; $self->trace_in;
 
-	my $job = $self->project->assigned_job or croak "No job assigned";
+	my $job = $self->project->assigned_job or die "No job assigned";
 	
 	return sprintf (
 		"%s/%s-%03d-%05d.avi",
@@ -102,7 +107,7 @@ sub avi_file {					# transcode output file
 sub target_avi_audio_file {
 	my $self = shift; $self->trace_in;
 
-	my $job = $self->project->assigned_job or croak "No job assigned";
+	my $job = $self->project->assigned_job or die "No job assigned";
 	
 	my $ext = $self->is_ogg ? $self->config('ogg_file_ext') : 'avi';
 
@@ -132,7 +137,7 @@ sub audio_video_psu_dir {
 sub audio_video_psu_file {
 	my $self = shift; $self->trace_in;
 
-	my $job = $self->project->assigned_job or croak "No job assigned";
+	my $job = $self->project->assigned_job or die "No job assigned";
 	
 	my $ext = $self->is_ogg ? $self->config('ogg_file_ext') : 'avi';
 
@@ -167,7 +172,7 @@ sub target_avi_file {				# final avi, merged PSUs + audio
 sub get_transcode_command {
 	my $self = shift; $self->trace_in;
 
-	my $job       = $self->project->assigned_job or croak "No job assigned";
+	my $job       = $self->project->assigned_job or die "No job assigned";
 
 	my $psu       = $job->psu;
 	my $chunk     = $job->chunk;
@@ -223,7 +228,7 @@ sub get_transcode_audio_command {
 	$command =~ s/\s+&& echo DVDRIP_SUCCESS//;
 
 	# add PSU selection and -W cluster parameter
-	my $job = $self->project->assigned_job or croak "No job assigned";
+	my $job = $self->project->assigned_job or die "No job assigned";
 
 	$command .=
 		" -S ".$job->psu.
@@ -240,7 +245,7 @@ sub get_merge_audio_command {
 	my %par = @_;
 	my ($vob_nr, $target_nr) = @par{'vob_nr','target_nr'};
 
-	my $job = $self->project->assigned_job or croak "No job assigned";
+	my $job = $self->project->assigned_job or die "No job assigned";
 
 	my $avi_file      = $self->audio_video_psu_file;
 	my $audio_file    = $self->target_avi_audio_file;
@@ -277,10 +282,10 @@ sub get_merge_audio_command {
 	} else {
 		$command .=
 			"dr_exec avimerge".
+			" -i $avi_file".
 			" -p $audio_file".
 			" -a $target_nr".
-			" -o $avi_file.merged".
-			" -i $avi_file &&".
+			" -o $avi_file.merged &&".
 			" mv $avi_file.merged $target_file &&".
 			" rm $audio_file &&".
 			" echo DVDRIP_SUCCESS";
@@ -292,7 +297,7 @@ sub get_merge_audio_command {
 sub get_merge_video_audio_command {
 	my $self = shift; $self->trace_in;
 	
-	my $job = $self->project->assigned_job or croak "No job assigned";
+	my $job = $self->project->assigned_job or die "No job assigned";
 
 	my $avi_chunks_dir       = $self->avi_chunks_dir;
 	my $audio_video_psu_file = $self->audio_video_psu_file;
