@@ -1,4 +1,4 @@
-# $Id: Config.pm,v 1.50 2005/07/23 08:14:15 joern Exp $
+# $Id: Config.pm,v 1.52 2005/08/01 19:31:10 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -86,19 +86,16 @@ my %CONFIG_PARAMETER = (
 		label => __"DVD device",
 		type => 'file',
 		value => "/dev/dvd",
-		rules => "file-writable",
 	},
 	dvd_mount_point => {
 		label => __"DVD mount point",
 		type => 'dir',
 		value => "/cdrom",
-		rules => "file-readable",
 	},
 	writer_device => {
 		label => __"Writer device file",
 		type => 'file',
 		value => "/dev/cdrom",
-		rules => "file-writable",
 	},
 	eject_command => {
 		label => __"Eject Command",
@@ -109,9 +106,9 @@ my %CONFIG_PARAMETER = (
 	play_dvd_command => {
 		label => __"DVD player command",
 		type  => 'string',
-		value => 'mplayer <dvd://%t -aid %(%a+%b) -chapter %c -dvdangle %m -dvd-device %d>',
+		value => 'mplayer <dvd://%t -aid %(%a+%b) -chapter %c -dvdangle %(%m+1) -dvd-device %d>',
 		presets => [
-			'mplayer <dvd://%t -aid %(%a+%b) -chapter %c -dvdangle %m -dvd-device %d>',
+			'mplayer <dvd://%t -aid %(%a+%b) -chapter %c -dvdangle %(%m+1) -dvd-device %d>',
 			'xine -a %a -p <dvd://%d/%t.%c>',
 		],
 		rules => "executable-command",
@@ -149,7 +146,6 @@ my %CONFIG_PARAMETER = (
 		label => __"Default data base directory",
 		type => 'dir',
 		value => "/CHANGE_ME",
-		rules => "dir-writable",
 	},
 	dvdrip_files_dir => {
 		label => __"Default directory for .rip project files",
@@ -695,7 +691,7 @@ sub save {
 	my $fh = FileHandle->new;
 
 	open ($fh, "> $filename") or die "can't write $filename";
-	print $fh q{# $Id: Config.pm,v 1.50 2005/07/23 08:14:15 joern Exp $},"\n";
+	print $fh q{# $Id: Config.pm,v 1.52 2005/08/01 19:31:10 joern Exp $},"\n";
 	print $fh "# This file was generated by Video::DVDRip Version $Video::DVDRip::VERSION\n\n";
 
 	print $fh ${$data_sref};
