@@ -1,4 +1,4 @@
-# $Id: CreateVobsub.pm,v 1.5 2004/04/11 23:36:20 joern Exp $
+# $Id: CreateVobsub.pm,v 1.6 2005/07/23 08:14:15 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -93,8 +93,7 @@ sub parse_output {
 	my $self = shift;
 	my ($line) = @_;
 
-	if ($line =~ /dr_progress/ ) {
-		$line =~ m!(\d+)/(\d+)\n.*?$!;
+	if ( $line =~ m!dr_progress:\s*(\d+)/(\d+)! ) {
 		$self->set_progress_cnt (10000*$1/$2);
 	}
 
