@@ -1,4 +1,4 @@
-# $Id: Split.pm,v 1.7.2.2 2006/03/18 11:23:01 joern Exp $
+# $Id: Split.pm,v 1.7 2004/04/11 23:36:20 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -108,7 +108,7 @@ sub parse_output {
 			);
 		}
 	} else {
-		if ( $line =~ /\(\d+-(\d+)\),\s+(.*?)\[.*?$/ ) {
+		if ( $line =~ /\(\d{6}-(\d+)\),\s+(.*?)\[.*?$/ ) {
 			$self->set_progress_cnt ($1);
 		}
 	}
