@@ -1,4 +1,4 @@
-# $Id: TranscodeVideo.pm,v 1.13.2.2 2006/03/18 11:23:01 joern Exp $
+# $Id: TranscodeVideo.pm,v 1.13 2005/04/24 12:30:39 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -161,7 +161,7 @@ sub parse_output {
 		$self->set_psu_frames($self->progress_cnt);
 	}
 
-	if ( $line =~ /\[(\d+-)?(\d+)\]/ ) {
+	if ( $line =~ /\[(\d{6}-)?(\d+)\]/ ) {
 		$self->set_progress_start_time(time)
 			if not $self->progress_start_time;
 		$self->set_progress_cnt(
