@@ -1,4 +1,4 @@
-# $Id: Probe.pm,v 1.21.2.2 2003/05/23 19:52:30 joern Exp $
+# $Id: Probe.pm,v 1.24 2005/07/23 08:14:15 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -9,6 +9,7 @@
 #-----------------------------------------------------------------------
 
 package Video::DVDRip::Probe;
+use Locale::TextDomain qw (video.dvdrip);
 
 use base Video::DVDRip::Base;
 
@@ -103,6 +104,7 @@ sub analyze {
 	$i = 0;
 	foreach my $audio ( @audio_tracks ) {
 		push @audio_track_objects, Video::DVDRip::Audio->new (
+			title		=> $title,
 			type		=> $audio->{type},
 			lang		=> $audio->{lang},
 			channels	=> $audio->{channels},
@@ -137,8 +139,6 @@ sub analyze {
 	if ( defined $sid ) {
 		# we have subtitles
 		$title->set_selected_subtitle_id (0);
-	} else {
-		$title->set_selected_subtitle_id (-1);
 	}
 
 	# Chapter frame counter
@@ -191,6 +191,7 @@ sub analyze_audio {
 			++$i;
 			$lines[$i] =~ /bitrate\s*=(\d+)/;
 			$title->audio_tracks->[$nr]->set_bitrate($1);
+			$title->audio_tracks->[$nr]->set_tc_ac3_bitrate($1);
 		}
 	}
 	
